@@ -1,7 +1,7 @@
 use Renard::Incunabula::Common::Setup;
 package Renard::Curie::Component::MainWindow::Role::ExceptionHandler;
 # ABSTRACT: A role for handling exceptions
-$Renard::Curie::Component::MainWindow::Role::ExceptionHandler::VERSION = '0.004';
+$Renard::Curie::Component::MainWindow::Role::ExceptionHandler::VERSION = '0.005';
 use Moo::Role;
 use Gtk3;
 use Glib 'TRUE', 'FALSE';
@@ -13,7 +13,7 @@ has _exception_handler => (
 );
 
 method _build__exception_handler() {
-	Glib->install_exception_handler( fun( $exception ) {
+	Glib->install_exception_handler( my $cb = fun( $exception ) {
 		if ( $exception->isa('Renard::Curie::Error::User::InvalidPageNumber') ) {
 			$self->_show_exception_dialog_box(
 				'Page number entered is invalid: entered "%s", should be between %s and %s.',
@@ -84,7 +84,13 @@ Renard::Curie::Component::MainWindow::Role::ExceptionHandler - A role for handli
 
 =head1 VERSION
 
-version 0.004
+version 0.005
+
+=head1 ATTRIBUTES
+
+=head2 EXCEPTION_DIALOG_LABEL_MAX_WIDTH_CHARS
+
+Constant with maximum width for exception dialog.
 
 =head1 AUTHOR
 
