@@ -1,20 +1,20 @@
 use Renard::Incunabula::Common::Setup;
 package Renard::Curie::Component::PageDrawingArea;
 # ABSTRACT: Component that implements document page navigation
-$Renard::Curie::Component::PageDrawingArea::VERSION = '0.004';
+$Renard::Curie::Component::PageDrawingArea::VERSION = '0.005';
 use Moo;
 
-use Renard::Incunabula::Frontend::Gtk3::Helper;
+use Intertangle::API::Gtk3::Helper;
 use Glib 'TRUE', 'FALSE';
 use Glib::Object::Subclass
 	'Gtk3::Bin',
-	signals => {
-		'update-scroll-adjustment' => {},
-	},
 	;
 use Renard::Incunabula::Common::Types qw(Bool InstanceOf);
 use Renard::Incunabula::Document::Types qw(PageNumber ZoomLevel);
-use Renard::Incunabula::Format::Cairo::Types qw(RenderableDocumentModel RenderablePageModel);
+use Renard::Block::Format::Cairo::Types qw(RenderableDocumentModel RenderablePageModel);
+
+use Renard::Curie::Component::JacquardCanvas;
+use Renard::Curie::Model::View::Scenegraph;
 
 has view_manager => (
 	is => 'ro',
@@ -35,20 +35,11 @@ has scrolled_window => (
 	isa => InstanceOf['Gtk3::ScrolledWindow'],
 );
 
-
 classmethod FOREIGNBUILDARGS(@) {
 	return ();
 }
 
 method BUILD(@) {
-	$self->signal_connect( 'update-scroll-adjustment', sub {
-		if( $self->view->can('update_scroll_adjustment') ) {
-			$self->view->update_scroll_adjustment(
-				$self->scrolled_window->get_hadjustment,
-				$self->scrolled_window->get_vadjustment,
-			);
-		}
-	});
 	$self->set_can_focus( TRUE );
 
 	$self->setup_drawing_area;
@@ -63,12 +54,18 @@ method BUILD(@) {
 			$self->update_view( $view );
 		}
 	);
+
 	$self->update_view( $self->view_manager->current_view );
-	$self->view->signal_emit('view-changed');
 }
 
 method setup_drawing_area() {
-	my $drawing_area = Gtk3::DrawingArea->new();
+	my $drawing_area = Renard::Curie::Component::JacquardCanvas->new(
+		sg => Renard::Curie::Model::View::Scenegraph->new(
+			view_manager => $self->view_manager,
+			view => $self->view,
+		)->graph,
+		scale => $self->view_manager->view_options->zoom_options->zoom_level,
+	);
 	$self->drawing_area( $drawing_area );
 	$drawing_area->signal_connect( draw => callback(
 			(InstanceOf['Gtk3::DrawingArea']) $widget,
@@ -86,25 +83,23 @@ method setup_drawing_area() {
 	$scrolled_window->set_policy( 'automatic', 'automatic');
 	$self->scrolled_window($scrolled_window);
 
-	my @adjustments = (
-		$self->scrolled_window->get_hadjustment,
-		$self->scrolled_window->get_vadjustment,
-	);
-	my $callback = fun($adjustment) {
-		$self->signal_emit('update-scroll-adjustment');
-	};
-	for my $adjustment (@adjustments) {
-		$adjustment->signal_connect( 'value-changed' => $callback );
-		$adjustment->signal_connect( 'changed' => $callback );
-	}
+	$drawing_area->add_events('scroll-mask');
 
 	my $vbox = $self->builder->get_object('page-drawing-component');
 	$vbox->pack_start( $scrolled_window, TRUE, TRUE, 0);
 }
 
-method refresh_drawing_area() {
+method refresh_drawing_area($view) {
 	return unless $self->drawing_area;
 
+	$self->drawing_area->set_data(
+		sg => Renard::Curie::Model::View::Scenegraph->new(
+			view_manager => $self->view_manager,
+			view => $view,
+		)->graph,
+		scale => $self->view_manager->view_options->zoom_options->zoom_level,
+	);
+
 	$self->drawing_area->queue_draw;
 }
 
@@ -113,47 +108,44 @@ method on_draw_page_cb( (InstanceOf['Cairo::Context']) $cr ) {
 	# callbacks with $self as the last argument.
 	$self->set_navigation_buttons_sensitivity;
 
-	$self->view->draw_page( $self->drawing_area, $cr );
-
 	my $page_number = $self->view->page_number;
-	if( $self->view->can('_first_page_in_viewport') ) {
-		$page_number = $self->view->_first_page_in_viewport;
+	my $placeholder_text = $page_number;
+	if( $self->drawing_area->can('_first_page_in_viewport') ) {
+		my @range = (
+			$self->drawing_area->_first_page_in_viewport,
+			$self->drawing_area->_last_page_in_viewport,
+		);
+		unless( $range[0] <= $page_number && $page_number <= $range[1] ) {
+			$self->view->page_number( $range[0] );
+		}
+		$placeholder_text = $range[0] == $range[1] ? "$range[0]" : "$range[0] - $range[1]";
 	}
 
 	$self->builder->get_object('page-number-entry')
-		->set_text($page_number);
+		->set_placeholder_text($placeholder_text);
 }
 
 
 method update_view($new_view) {
-	# so that the widget can take input
-	$self->view->signal_connect( 'view-changed', sub {
-		$self->signal_emit('update-scroll-adjustment');
-		if( $self->view->can('get_size_request') ) {
-			if( $self->drawing_area ) {
-				$self->drawing_area->set_size_request(
-					$self->view->get_size_request
-				);
-				$self->refresh_drawing_area;
-			}
-		} else {
-			$self->refresh_drawing_area;
+	$new_view->signal_connect(
+		'scroll-to-page', fun( $view, $page_number ) {
+			$self->drawing_area->scroll_to_page( $page_number );
 		}
-	} );
-
-	$self->view->signal_emit('view-changed');
+	);
+	$self->refresh_drawing_area( $new_view );
 }
 
 with qw(
-	Renard::Incunabula::Frontend::Gtk3::Component::Role::FromBuilder
-	Renard::Incunabula::Frontend::Gtk3::Component::Role::UIFileFromPackageName
+	Intertangle::API::Gtk3::Component::Role::FromBuilder
+	Intertangle::API::Gtk3::Component::Role::UIFileFromPackageName
 
 	Renard::Curie::Component::PageDrawingArea::Role::KeyBindings
 	Renard::Curie::Component::PageDrawingArea::Role::MouseScrollBindings
 	Renard::Curie::Component::PageDrawingArea::Role::NavigationButtons
 	Renard::Curie::Component::PageDrawingArea::Role::PageEntry
 	Renard::Curie::Component::PageDrawingArea::Role::PageLabel
-	Renard::Curie::Component::PageDrawingArea::Role::ScrollWindow
+
+	Renard::Curie::Component::PageDrawingArea::Role::HighlightCurrentSentence
 );
 
 
@@ -171,7 +163,7 @@ Renard::Curie::Component::PageDrawingArea - Component that implements document p
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 EXTENDS
 
@@ -193,6 +185,12 @@ version 0.004
 
 =over 4
 
+=item * L<Intertangle::API::Gtk3::Component::Role::FromBuilder>
+
+=item * L<Intertangle::API::Gtk3::Component::Role::UIFileFromPackageName>
+
+=item * L<Renard::Curie::Component::PageDrawingArea::Role::HighlightCurrentSentence>
+
 =item * L<Renard::Curie::Component::PageDrawingArea::Role::KeyBindings>
 
 =item * L<Renard::Curie::Component::PageDrawingArea::Role::MouseScrollBindings>
@@ -203,12 +201,6 @@ version 0.004
 
 =item * L<Renard::Curie::Component::PageDrawingArea::Role::PageLabel>
 
-=item * L<Renard::Curie::Component::PageDrawingArea::Role::ScrollWindow>
-
-=item * L<Renard::Incunabula::Frontend::Gtk3::Component::Role::FromBuilder>
-
-=item * L<Renard::Incunabula::Frontend::Gtk3::Component::Role::UIFileFromPackageName>
-
 =back
 
 =head1 ATTRIBUTES
@@ -267,16 +259,6 @@ Sets up the signals for a new view.
 
 Callback that draws the current page on to the L</drawing_area>.
 
-=head1 SIGNALS
-
-=over 4
-
-=item *
-
-C<update-scroll-adjustment>: called when the widget has been horizontally or vertically scrolled
-
-=back
-
 =head1 AUTHOR
 
 Project Renard
